@@ -14,4 +14,9 @@ y <- colSums(y)
 one <- as.vector(rep(1,n.y))  #to duplicate x n.y times
 one.y <- as.vector(rep(1,n.x)) #to duplicate y n.x times
 xy  <- x %*% t(one) + t(y %*% t(one.y) )  #sum the vectors in a rectangular array
-  return(xy) }
\ No newline at end of file
+  return(xy) }
+  
+ "tr" <- 
+function(m) {
+if (!is.matrix(m) |(dim(m)[1] != dim(m)[2]) ) stop ("m must be a square matrix")
+return(sum(diag(m))) }
\ No newline at end of file
